@@ -1,24 +1,26 @@
-from django.db import models
 from django.contrib.auth.models import AbstractUser, BaseUserManager
+from django.db import models
 from django.utils import timezone
 from django.utils.translation import ugettext_lazy as _
-from django_mysql.models import JSONField
 
 
 class UserManager(BaseUserManager):
-    """默认创建用户时需要 email，自己实现的去掉了 email"""
+    """
+    Email is required to create users by default, and
+    the implementation here removes the email
+    """
     use_in_migrations = True
 
     def _create_user(self, username, password, is_staff, **extra_fields):
         """
-        Creates and saves a User with the given username, email and password.
+        Creates and saves a User with the given username and password.
         """
         now = timezone.now()
         if not username:
             raise ValueError('The given username must be set')
-        user = self.model(username=username,
-                          is_staff=is_staff, is_active=True,
-                          date_joined=now, **extra_fields)
+        user = self.model(
+            username=username, is_staff=is_staff, is_active=True, date_joined=now, **extra_fields
+        )
         user.set_password(password)
         user.save(using=self._db)
         return user
@@ -30,7 +32,14 @@ class UserManager(BaseUserManager):
         return self._create_user(username, password, True, **extra_fields)
 
 
-class User(AbstractUser):
-    mobile = models.CharField('手机号', max_length=16, default='', db_index=True, blank=True)
+class EnhancedAbstractUser(AbstractUser):
+    mobile = models.CharField(_('mobile'), max_length=16, default='', db_index=True, blank=True)
+    nickname = models.CharField(_('nickname'), max_length=128, default='')
+    avatar = models.CharField(_('avatar'), max_length=256, default='')
 
     objects = UserManager()
+
+    class Meta:
+        verbose_name = _('user')
+        verbose_name_plural = _('users')
+        abstract = True
