@@ -6,13 +6,11 @@ from .say import *
 def get_project_name():
     """Determined the project path
 
-    # TODO: the function must be improved
-    There will be only one folder in root directory,
-    it's the project name
+    project settings folder contains `wsgi.py`
     """
     for path in os.listdir('.'):
-        if os.path.isdir(path):
-            print('Determined the project path is: ', path)
+        if os.path.exists(os.path.join(path, 'wsgi.py')):
+            say(f'Determined the project path is: {path}')
             return path
 
 
@@ -27,7 +25,23 @@ def get_settings_path(project=None):
     """Determined the project path"""
     base_dir = os.getcwd()
     project = project or get_project_name()
-    return os.path.join(base_dir, project, project, 'settings')
+
+    path = os.path.join(base_dir, project, project, 'settings')
+    if os.path.exists(path):
+        return path
+
+    path = os.path.join(base_dir, project, 'settings')
+    if os.path.exists(path):
+        return path
+
+    raise Exception('Determine project path failed!')
+
+
+def get_root_urls_path(project=None):
+    """Determined the root urls path"""
+    base_dir = os.getcwd()
+    project = project or get_project_name()
+    return os.path.join(base_dir, project, 'urls.py')
 
 
 def copy_template_to_file(file_path, target_path, **kwargs):
